function out = TSB(k,C0,cota)
    
% Fourier transfer function (from bed topography perturbation to surface topography perturbation)
% based on Eqns (72) to (75) of the paper by Gudmundsson (2003)
%
% INPUTS:
% k - dimensionless wavenumber (as a  scalar or row or column vector)
% C0 - basal slip ratio at a given position
% cota - cot(alpha) (where alpha is surface slope angle) at a given position
% 
% out - complex transfer function as row or column vector (following format of k)


% make ingredients
CA = cota + (0.*k);
C1 = C0 + (0.*k);
Vs = 1 + C1;
C2 = C1.^2;
%
k2 = k.^2;
sh = sinh(k);
ch = cosh(k);
%
f = ch + k.*C1.*sh;

% transfer function
out = k2 .* (Vs.*f+(Vs+C2.*k2).*ch) ./ ( k2.*Vs.*(1 + k2.*Vs + f.*ch) - i*CA.*(f.*sh-k) );

% Correct the behaviour at k == 0 (where the above expression gives NaN) is that this transfer function = 1: 
out(k==0) = 1;



    

